@@ -1,7 +1,9 @@
 from .base import BaseRecommender
 from .fm import FMRecommender
+from .ials import IALSRecommender
 
 __all__ = [
     "BaseRecommender",
     "FMRecommender",
+    "IALSRecommender",
 ]
